==> apache-arrow-rs-53.4.0.tar.gz: apache-arrow-rs-53.4.0/arrow-array/benches/gc_view_types.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

use arrow_array::StringViewArray;
use criterion::*;

fn gen_view_array(size: usize) -> StringViewArray {
    StringViewArray::from_iter((0..size).map(|v| match v % 3 {
        0 => Some("small"),
        1 => Some("larger than 12 bytes array"),
        2 => None,
        _ => unreachable!("unreachable"),
    }))
}

fn criterion_benchmark(c: &mut Criterion) {
    let array = gen_view_array(100_000);

    c.bench_function("gc view types all", |b| {
        b.iter(|| {
            black_box(array.gc());
        });
    });

    let sliced = array.slice(0, 100_000 / 2);
    c.bench_function("gc view types slice half", |b| {
        b.iter(|| {
            black_box(sliced.gc());
        });
    });
}

criterion_group!(benches, criterion_benchmark);
criterion_main!(benches);

==> apache-arrow-rs-55.2.0.tar.gz: apache-arrow-rs-55.2.0/arrow-array/benches/gc_view_types.rs <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

use arrow_array::StringViewArray;
use criterion::*;
use std::hint;

fn gen_view_array(size: usize) -> StringViewArray {
    StringViewArray::from_iter((0..size).map(|v| match v % 3 {
        0 => Some("small"),
        1 => Some("larger than 12 bytes array"),
        2 => None,
        _ => unreachable!("unreachable"),
    }))
}

fn criterion_benchmark(c: &mut Criterion) {
    let array = gen_view_array(100_000);

    c.bench_function("gc view types all", |b| {
        b.iter(|| {
            hint::black_box(array.gc());
        });
    });

    let sliced = array.slice(0, 100_000 / 2);
    c.bench_function("gc view types slice half", |b| {
        b.iter(|| {
            hint::black_box(sliced.gc());
        });
    });
}

criterion_group!(benches, criterion_benchmark);
criterion_main!(benches);
